@@ -1,20 +1,20 @@
 """Provides an extension to allow front matter in the template"""
-from jinja2 import Environment
+from typing import TYPE_CHECKING
 from jinja2.ext import Extension
 
 from ..defaults import FRONT_MATTER_LANG
 
+if TYPE_CHECKING:
+    from jinja2 import Environment
+
 
 class FrontMatterExtension(Extension):
     """This extension allows to have front matter"""
 
-    # pylint: disable=abstract-method
-
-    def __init__(self, environment: Environment) -> None:
+    def __init__(self, environment: "Environment") -> None:
         super().__init__(environment)
         environment.extend(front_matter_lang=FRONT_MATTER_LANG)
 
-    # pylint: disable=unused-argument
     def preprocess(self, source: str, name: str, filename: str = None) -> str:
         """Preprocess sourcee to extract front matter"""
         import frontmatter
